@@ -39,8 +39,8 @@ void Bank::open_stream(int i)
     buffered_file[i]->stream = gzopen(buffered_file[i]->fname,"r");
     if (buffered_file[i]->stream == NULL)
     {
-       fprintf(stderr, "\nERROR: cannot open reads file %s, exit\n",buffered_file[i]->fname);
-       exit(1);
+        printf("error opening file: %s\n",buffered_file[i]->fname);
+        exit(1);
     }
 }
 // and close it
@@ -214,6 +214,25 @@ bool  Bank::get_next_seq_from_file(char **nseq, int *len, int file_id)
     return get_next_seq_from_file(nseq,NULL,len,NULL,file_id);
 }
 
+//wrapper with notif when changing file
+bool Bank::get_next_seq(char **nseq, char **cheader, int *len, int *hlen, int  * id_file)
+{
+    * id_file = index_file ;
+    bool success = get_next_seq_from_file(nseq,cheader,len,hlen,index_file);
+    if (success)
+        return true;
+    
+    // cycle to next file if possible
+    if ( index_file < nb_files-1 )
+    {
+        close_stream(index_file);
+        index_file++;
+        open_stream(index_file);
+        return get_next_seq(nseq,cheader, len,hlen, id_file);
+    }
+    return false;
+}
+
 // wrapper
 bool Bank::get_next_seq(char **nseq, char **cheader, int *len, int *hlen)
 {
@@ -238,6 +257,12 @@ bool Bank::get_next_seq(char **nseq, int *len)
   return get_next_seq(nseq,NULL,len,NULL);
 }
 
+// wrapper
+bool Bank::get_next_seq(char **nseq, int *len, int * id_file)
+{
+    return get_next_seq(nseq,NULL,len,NULL,id_file);
+}
+
 
 // had to move the Bank(x,x) constructor to an init() to avoid calling a constructor inside the Bank(x) constructor
 void Bank::init(char **fname, int nb_files_)
@@ -252,7 +277,7 @@ void Bank::init(char **fname, int nb_files_)
     {
         char *buffer = (char*)malloc(BUFSIZ);
         strerror_r( errno, buffer, BUFSIZ ); // get string message from errno
-        printf("error during fopen: %s   %s \n",buffer,fname[0]);
+        printf("error during fopen, filename: %s (buffer: %p) \n", fname[0], buffer);
         free(buffer);
         exit(1);
     }
@@ -299,6 +324,15 @@ void Bank::init(char **fname, int nb_files_)
 
     }
 
+    // initialize the buffers
+    buffered_file = (buffered_file_t**) malloc(sizeof(buffered_file_t *)*nb_files);
+    for (i=0; i<nb_files; i++)
+    {
+        buffered_file[i] = (buffered_file_t *)calloc(1, sizeof(buffered_file_t));
+        buffered_file[i]->buffer = (unsigned char*) malloc(BUFFER_SIZE); 
+        buffered_file[i]->fname = strdup(fname[i]);
+    }
+
     // estimate total size of files
     for (i=0; i<nb_files; i++)
     {
@@ -313,18 +347,10 @@ void Bank::init(char **fname, int nb_files_)
         else
             estimated_filesize = fsize(fname[i]);
 
+        buffered_file[i]->estimated_filesize = estimated_filesize;
         filesizes += estimated_filesize;
     }
 
-    // initialize the buffers
-    buffered_file = (buffered_file_t**) malloc(sizeof(buffered_file_t *)*nb_files);
-    for (i=0; i<nb_files; i++)
-    {
-        buffered_file[i] = (buffered_file_t *)calloc(1, sizeof(buffered_file_t));
-        buffered_file[i]->buffer = (unsigned char*) malloc(BUFFER_SIZE); 
-        buffered_file[i]->fname = strdup(fname[i]);
-    }
-
     rewind_all(); // initialize the get_next_seq iterator to the first file
 
     // init read and dummy (for readname and quality)
@@ -375,37 +401,43 @@ void Bank::close()
 }
 
 // estimate the volume of all redundant kmers in the reads, if they were to be stored in 2bits
+// from the first 100k reads of each file
 uint64_t Bank::estimate_kmers_volume(int k)
 {
-
     char * rseq;
     int readlen;
-    int NbRead = 0;
-    //int kmer_nbits = std::max(64,(int)pow(2,ceilf(log2f(2*k)))); // Bank assumes that a kmer is stored in the smallest integer type (e.g. uint64_t or uint128_t) // not accurate anymore with _ttmath/_largeint
     int kmer_nbits = sizeof(kmer_type)*8;
     rewind_all();
-    uint64_t volume = 0;
+    uint64_t total_volume = 0;
 
-    while (get_next_seq(&rseq,&readlen))
+    while ( index_file < nb_files )
     {
-        if (readlen >= k)
-            volume += (readlen-k+1) * (uint64_t) kmer_nbits;
-        if (NbRead++ == 1000)
-            break;
-    }
+        open_stream(index_file);
+        int NbRead = 0;
+        uint64_t volume_for_file = 0;
+        while (get_next_seq_from_file(&rseq,NULL,&readlen,NULL,index_file))
+        {
+            if (readlen >= k)
+                volume_for_file += (readlen-k+1) * (uint64_t) kmer_nbits;
+            if (NbRead++ == 100000) // somehow less than 100000 is bad for our ion torrent tag1.fasta file
+                break;
+        }
+        if ( gztell(buffered_file[index_file]->stream) != 0) // would be empty file
+        {
+            volume_for_file = (uint64_t) ( ( (float) volume_for_file ) * ( ( (float)(buffered_file[index_file]->estimated_filesize)) / ((float) gztell(buffered_file[index_file]->stream)) ) );
+            total_volume += volume_for_file;
+        }
+        close_stream(index_file);
+        index_file++;
+    } 
 
-    if ( gztell(buffered_file[index_file]->stream) == 0) // empty file
-        return 1;
-
-    volume = (uint64_t) ( ( (float) volume ) * ( ( (float)filesizes ) / ((float) gztell(buffered_file[index_file]->stream)) ) );
-
-    volume = volume / 1024 /1024 /8; // put it in MB
+    total_volume = total_volume / 1024 /1024 /8; // put it in MB
     
-    if (volume == 0)  // tiny files fix
-        volume = 1;
+    if (total_volume == 0)  // tiny files fix
+        total_volume = 1;
 
     rewind_all();
-    return volume;
+    return total_volume;
 }
 
 // estimate the number of reads
@@ -443,10 +475,9 @@ int Bank::estimate_max_readlen()
     int max_readlen = 0;
     uint64_t volume = 0;
 
-    index_file = 0;
-    
     while ( index_file < nb_files )
     {
+        open_stream(index_file);
         int NbRead = 0;
         while (get_next_seq_from_file(&rseq,NULL,&readlen,NULL,index_file))
         {
@@ -454,10 +485,11 @@ int Bank::estimate_max_readlen()
             if (NbRead++ == 10000)
                 break;
         }
+        close_stream(index_file);
         index_file++;
     } 
 
-    index_file = 0;
+    rewind_all();
     return max_readlen;
 }
 
@@ -622,8 +654,11 @@ size_t BinaryBank::read_element_buffered( void *element)
     {
         cpt_buffer=fread(buffer, sizeElement,buffer_size_nelem, binary_read_file);
         if (cpt_buffer==0) return 0;
+        cpt_init_buffer = cpt_buffer;
     }
-    memcpy(element, (unsigned char *)buffer + (cpt_buffer-1) * sizeElement, sizeElement);
+    //memcpy(element, (unsigned char *)buffer + (cpt_buffer-1) * sizeElement, sizeElement);//ca les depile en sens inverse de la lecture
+    memcpy(element, (unsigned char *)buffer + (cpt_init_buffer -1 - (cpt_buffer-1)) * sizeElement, sizeElement);//ca les depile dans le meme  sens que la lecture
+
     cpt_buffer --;
     return cpt_buffer+1; // nb remaining before read
 }
@@ -766,6 +801,28 @@ void BinaryReads::open(bool write)
 }
 
 
+void BinaryReads::mark_newfile()
+{
+    unsigned int block_size =0;
+  //flush previous buffer
+    if(cpt_buffer)
+    {
+        //printf("close :write block %i \n",cpt_buffer);
+        block_size = cpt_buffer;
+        fwrite(&block_size, sizeof(unsigned int), 1, binary_read_file); // block header
+        if (!fwrite(buffer, 1, cpt_buffer, binary_read_file))
+        {
+            printf("error: can't fwrite (disk full?)\n");
+            exit(1);
+        }
+    }
+    cpt_buffer=0;
+    
+    //then write empty block == mark of a new file
+    block_size =0;
+    fwrite(&block_size, sizeof(unsigned int), 1, binary_read_file); // block header with 0
+
+}
 
 //format is
 // 32 bit integer = readlen,  then seq in binary
@@ -909,9 +966,15 @@ int KmersBuffer::readkmers()
         if( ! fread(&block_size,sizeof(unsigned int),1, binary_read_file)) //read block header
         {
             funlockfile(binary_read_file);
-            return 0; // no more blocks to read
+            return -1; // no more blocks to read
         }
         
+        // block_size = 0 is a marker to indicate new read file, when it happens return -2
+        if(block_size==0)
+        {
+            return -2 ;
+        }
+        ///
         
         if(block_size >= read_write_buffer_size) // block buffer need to be enlarged
         {
@@ -1016,7 +1079,6 @@ int KmersBuffer::readkmers()
     //while buffer is non empty, we 'expand' a sequence into  binSeq_extended
     //then we parse binSeq_extended to store kmers in the kmers_buffer
     
-    
     return nkmers;
     
     
