@@ -7,11 +7,15 @@
 
 #define SINGLE_BAR 1
 
+#define SEP
 bool clear_cache = false; // clear file cache from memory (for timing only)
 
 bool hybrid_mode = false;
 bool use_hashing = true; // use hashing instead of sorting (better control of memory)
 float load_factor = 0.7;
+
+bool separate_count = false ;  // count separately the multiple read sets, only works with use_hashing, needs define SEP and use_hashing=true
+
 bool use_compressed_reads = true ; // true; // write compressed read file
 int optimism = 1; // optimism == 1 mean that we garantee worst case the memory usage, any value above assumes that, on average, a k-mer will be seen 'optimism' times
 
@@ -63,7 +67,6 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
     // estimate number of iterations
     uint64_t volume = Sequences->estimate_kmers_volume(sizeKmer);
     uint32_t nb_passes = ( volume / max_disk_space ) + 1;
-
     
     int nb_threads=1;
     
@@ -123,6 +126,7 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
     }
     while (1);
 
+
  // volume / (sizeof(kmer_type)*4)   is approx size of read file stored in binary, read nb_passes -1 times
     uint64_t total_IO =   volume * 2LL * 1024LL*1024LL   ;// in bytes  +   nb_passes * ( volume / (sizeof(kmer_type)*4) )    ; // in bytes
     uint64_t temp_IO = 0;
@@ -151,17 +155,35 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
         SolidKmers->flush(0);
     }
 
-    int64_t estimated_NbReads = Sequences->estimate_nb_reads();
+    int64_t estimated_NbReads = Sequences->estimate_nb_reads(); // only used in progress prints
     char * rseq;
     int readlen;
     int64_t NbSolid = 0;
     int64_t * NbSolid_omp = (int64_t  *) calloc(nb_threads,sizeof(int64_t));
-    //long total_kmers_per_partition[nb_partitions]; //guillaume probably commented it because updating this variable would require synchronization
+    
+#ifdef SEP
+
+    long total_kmers_per_partition[nb_partitions]; //guillaume probably commented it because updating this variable would require synchronization
+
+    for (int jj=0; jj<nb_partitions; jj++) {
+        total_kmers_per_partition[jj]=0;
+    }
+    
+    long kmers_perparti_perfile[nb_partitions][1000];//store cumulated counter
+    for (int ii=0; ii<nb_partitions; ii++) {
+        for (int jj=0; jj<1000; jj++) {
+            kmers_perparti_perfile[ii][jj]=0;
+        }
+    }
+    
+#endif
+    
     long distinct_kmers_per_partition[nb_partitions];
     uint64_t  * histo_count = (uint64_t  *) calloc(10001,sizeof(uint64_t));
 
 
 #if OMP
+    printf("coucou coucou coucou \n \n \n");
     uint64_t  **  histo_count_omp = (uint64_t  **) calloc(nb_threads,sizeof(uint64_t *));
     for(int ii=0;ii<nb_threads;ii++)
     {
@@ -190,11 +212,25 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
         progress_conversion.init(estimated_NbReads,"First step: Converting input file into Binary format");
         
         binread = new BinaryReads(return_file_name(binary_read_file),true);
-
+#ifdef SEP
+        int file_id =0;
+        int prev_file_id =0;
+#endif
+        
         Sequences->rewind_all();
         while(1)
         {
+#ifdef SEP
+            if(! Sequences->get_next_seq(&rseq,&readlen,&file_id)) break; // read  original fasta file
+            if(separate_count && (file_id != prev_file_id))
+            {
+                //printf("new file \n");
+                prev_file_id = file_id;
+                binread->mark_newfile();
+            }
+#else
             if(! Sequences->get_next_seq(&rseq,&readlen)) break; // read  original fasta file
+#endif
             if(readlen > max_read_length) // realloc kmer_table_seq if needed
             {
                 max_read_length = 2*readlen;
@@ -264,6 +300,21 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
     for (uint32_t current_pass = 0; current_pass < nb_passes; current_pass ++)
     {
         
+#ifdef SEP
+        if(separate_count)
+        {
+            for (int jj=0; jj<nb_partitions; jj++) {
+                total_kmers_per_partition[jj]=0;
+            }
+            
+            for (int ii=0; ii<nb_partitions; ii++) {
+                for (int jj=0; jj<1000; jj++) {
+                    kmers_perparti_perfile[ii][jj]=0;
+                }
+            }
+        }
+#endif
+        
         if(use_compressed_reads ) //open binary reads for reading
             binread->open(false);
         
@@ -290,10 +341,10 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
 #endif
      
 
-        
+        int file_id=0;
         //current_pass> 0 &&
 #if OMP
-#pragma omp parallel if(use_compressed_reads)  num_threads(nb_threads)
+#pragma omp parallel if(use_compressed_reads && ! separate_count)  num_threads(nb_threads)
 #endif
         {
             int64_t  nbkmers_written =0;
@@ -321,7 +372,20 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
                 if(use_compressed_reads) // && current_pass>0
                 {
                     nread = kbuff->readkmers();
-                    if(! nread) break;
+#ifdef SEP
+                    if(separate_count && (nread == -2))
+                    {
+                        //printf("New file notified, filling parti\n");
+                        for (int kk=0; kk< nb_partitions; kk++) {
+                            kmers_perparti_perfile[kk][file_id] =  total_kmers_per_partition [kk];
+                            //printf(".. total_kmers_per_partition[%i] =  %li\n",kk, total_kmers_per_partition [kk]);
+                        }
+                        file_id++;
+                        continue;
+                    }
+#endif
+                    
+                    if(nread < 0) break;
                     NbRead+= nread;
                     tempread+= nread;
                 }
@@ -333,7 +397,6 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
                         max_read_length = 2*readlen;
                         kmer_table_seq = (kmer_type * ) realloc(kmer_table_seq,sizeof(kmer_type)*max_read_length);
                     }
-
                 }
 
 //                if(use_compressed_reads ) //write compressed read file at first pass //&& current_pass==0
@@ -357,6 +420,7 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
                     NbRead++;
                 }
 
+                //printf("Encountering empty block \n");
                 nbkmers_written= 0;
                 //compute the kmers stored in the buffer kmer_table
                 for (i=0; i<nbkmers; i++)
@@ -392,8 +456,13 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
 
                     nbkmers_written++;
 
+
+                    
                     redundant_partitions_file[p]->write_element_buffered(&lkmer,tid); // save this kmer to the right partition file
-                    // total_kmers_per_partition[p]++; // guillaume probably commented it because updating this variable would require synchronization
+#ifdef SEP
+                    if(separate_count)
+                        total_kmers_per_partition[p]++; // guillaume probably commented it because updating this variable would require synchronization
+#endif
 
                 }
                 //NbRead++;
@@ -475,7 +544,7 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
         // TODO to guillaume: remove that todo above, because it is done, right?
 #if OMP 
         //omp_set_numthreads(2);  //num_threads(2) //if(!output_histo) num_threads(nb_threads)
-#pragma omp parallel for private (p)  num_threads(nb_threads)
+#pragma omp parallel for if (! separate_count) private (p)  num_threads(nb_threads)
 #endif        
         // load, sort each partition to output solid kmers
         for (int p=0;p<nb_partitions;p++)
@@ -502,10 +571,35 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
                 OAHash hash(max_memory*1024LL*1024LL);
                 uint64_t nkmers_read=0;
                 
+                uint64_t nkmers_read_all=0;
+                
+                file_id = 0;
                 while (redundant_partitions_file[p]->read_element_buffered (&lkmer))
                 {
+                    
+
                     hash.increment(lkmer);
                     nkmers_read++;
+#ifdef SEP
+                    nkmers_read_all++;
+                    if( separate_count && (kmers_perparti_perfile[p][file_id]==nkmers_read_all))
+                    {
+                        //printf("Parsing parti .. detected end of file %i at %lli  parti %i \n",file_id,nkmers_read_all,p);
+                        file_id++;
+
+                        //faire raz des cpts < seuil de la hash, devrait etre suffisant ...
+                         hash.start_iterator();
+                        while (hash.next_iterator())
+                        {
+                             if (hash.iterator->value < nks)
+                             {
+                                 hash.iterator->value = -1 ; // 0 is not valid in oahash, emulate it with -1
+                             }
+                        }
+                    }
+
+#endif
+
 #if SINGLE_BAR
                     if(verbose==0 && nkmers_read==10000)
                     {
@@ -527,7 +621,16 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
                 hash.start_iterator();
                 while (hash.next_iterator())
                 {
+                    
+#ifdef SEP
+                    int value = hash.iterator->value;
+                    if(value==-1) value = 0; // desemulate -1
+                    uint_abundance_t abundance = value;
+
+#else
                     uint_abundance_t abundance = hash.iterator->value;
+             
+#endif
                     if(output_histo)
                     {
                         uint_abundance_t saturated_abundance;
@@ -542,6 +645,7 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
                     }
                     if (abundance >= nks && abundance <= max_couv)
                     {
+                        
                         SolidKmers->write_element_buffered(&(hash.iterator->key),tid);
                         
                         NbSolid_omp[tid]++;
