@@ -74,7 +74,7 @@ int MIN_DIST;
 int BUBBLE_COUNT_OFFSET;
 int MAX_BRANCHES;
 
-bool OUTPUT_CONTEXT; 
+bool OUTPUT_CONTEXT;
 bool OUTPUT_SNPS;
 bool OUTPUT_PATH;
 
@@ -97,7 +97,7 @@ int nb_nodes;
    complementary node. The function has to convert it. */
 string getSeq(int i)
 {
-  return (i < (int)seqs.size()) ? string(seqs[i]) : reverse_complement(string(seqs[i % (int)seqs.size()])); 
+  return (i < (int)seqs.size()) ? string(seqs[i]) : reverse_complement(string(seqs[i % (int)seqs.size()]));
 }
 
 
@@ -277,7 +277,7 @@ typedef pair<int, int> ii;
    source to every node. The results are in dist. */
 void dijkstra(int max_dist, int source, map<int,int>& dist, WeightedDigraph& G)
 {
-  priority_queue<ii,vector<ii>, greater<ii> > Q; 
+  priority_queue<ii,vector<ii>, greater<ii> > Q;
 
   dist[source] = 0;
   Q.push(ii(0, source));
@@ -304,7 +304,7 @@ void dijkstra(int max_dist, int source, map<int,int>& dist, WeightedDigraph& G)
           }
         }
       }
-  }  
+  }
 }
 
 /* Checks if the distance from s to t is smaller than max_dist */
@@ -353,7 +353,7 @@ int inDegree(int node, WeightedDigraph& G)
 int nbBranchingNodes(vector<int>& p_nodes, WeightedDigraph& G)
 {
   int nb = 0;
-  
+
   // Disregard the initial and final nodes.
   for (int i = 1; i < (int)p_nodes.size()-1; i++)
     if (G.outDegree(p_nodes[i]) != 1 ||  inDegree(p_nodes[i],G) != 1)
@@ -383,7 +383,7 @@ void listPairCompatible(int s1, int a1, int p1, vector<int>& p1_nodes, int s2, i
   if (nbBranchingNodes(p1_nodes, G) > MAX_BRANCHES || nbBranchingNodes(p2_nodes, G) > MAX_BRANCHES)
     return;
 
-  if (s1 == s2 && (p1_nodes.size() != 1 || p2_nodes.size() != 1)) 
+  if (s1 == s2 && (p1_nodes.size() != 1 || p2_nodes.size() != 1))
   {
     if ( p1 >= (beta + G.node_cost[s1]) && p2 >= (beta + G.node_cost[s2]) )
     {
@@ -393,7 +393,7 @@ void listPairCompatible(int s1, int a1, int p1, vector<int>& p1_nodes, int s2, i
       {
         string upper_seq = path2seq(p1_nodes, OUTPUT_CONTEXT, true);
         string lower_seq = path2seq(p2_nodes, OUTPUT_CONTEXT, true);
-	int upper_b = nbBranchingNodes(p1_nodes,G), lower_b = nbBranchingNodes(p2_nodes,G); 
+	int upper_b = nbBranchingNodes(p1_nodes,G), lower_b = nbBranchingNodes(p2_nodes,G);
         bool swp = false;
 
         if (upper_seq.size() < lower_seq.size())
@@ -427,10 +427,10 @@ void listPairCompatible(int s1, int a1, int p1, vector<int>& p1_nodes, int s2, i
     }
     return;
   }
-  
+
   if (G.adjListSz(s1) == 0 && G.adjListSz(s2) == 0)
     return;
-  
+
   int u = (G.adjListSz(s1) != 0) ? s1 : s2;
 
   G.removed[u] = true;
@@ -451,7 +451,7 @@ void listPairCompatible(int s1, int a1, int p1, vector<int>& p1_nodes, int s2, i
         listPairCompatible(s1, a1, p1, p1_nodes, v, a2 - cost, p2 + cost, p2_nodes, G);
         p2_nodes.pop_back();
       }
-    }      
+    }
   }
   G.removed[u] = false;
 
@@ -460,7 +460,7 @@ void listPairCompatible(int s1, int a1, int p1, vector<int>& p1_nodes, int s2, i
     vector<WeightedEdge> adj_u;
     adj_u.swap(G.adj_list[u]);
     if ((u == s1 && dist_st(a2, s2, s1, G)) || (u == s2 && dist_st(a1, s1, s2, G)))
-      listPairCompatible(s1, a1, p1, p1_nodes, s2, a2, p2, p2_nodes, G);  
+      listPairCompatible(s1, a1, p1, p1_nodes, s2, a2, p2, p2_nodes, G);
     G.adj_list[u].swap(adj_u);
   }
 }
@@ -470,7 +470,7 @@ void bfs(WeightedDigraph &G, int source, set<int> &in_sub)
 {
   queue<int> Q;
   map<int, int> dist;
-    
+
   Q.push(source);
   dist[source] = 0;
   while (!Q.empty())
@@ -489,7 +489,7 @@ void bfs(WeightedDigraph &G, int source, set<int> &in_sub)
 	Q.push(v);
 	dist[v] = d + 1;
       }
-    }  
+    }
     // We don't compress non-branching paths to an edge, but to a
     // vertex, this means that each non-branching vertex is followed
     // by to branching vertices. Implying that a path with
@@ -499,7 +499,7 @@ void bfs(WeightedDigraph &G, int source, set<int> &in_sub)
     // (MAX_BRANCHES+1).
     if (d > 2*(MAX_BRANCHES+1))
       return;
-  }  
+  }
   dist.clear();
 }
 
@@ -507,20 +507,20 @@ void bfs(WeightedDigraph &G, int source, set<int> &in_sub)
    listPairCompatible function. */
 void listAllBubbles(WeightedDigraph& G, int k_value, int UL_MAX, int LL_MAX, int LL_MIN)
 {
-  int a1 = LL_MAX - (k_value - 1), 
-      a2 = UL_MAX - (k_value - 1); 
+  int a1 = LL_MAX - (k_value - 1),
+      a2 = UL_MAX - (k_value - 1);
   beta = LL_MIN - (k_value - 1);
 
   for (int v = 0; v < (int)G.adj_list.size(); v++)
   {
     in_sub.clear();
     bfs(G, v, in_sub);
-    
+
     vector<int> p1_nodes, p2_nodes;
 
     p1_nodes.push_back(v); p2_nodes.push_back(v);
     listPairCompatible(v, a1, 0, p1_nodes, v, a2, 0, p2_nodes, G);
-  }  
+  }
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -537,7 +537,7 @@ void printSummary( FILE* stream, int num_bubbles )
 }
 
 void printUsageAndExit( char * name )
-{ 
+{
   fprintf( stderr, "Usage: %s infofile contents_file_edges contents_file_nodes basename_edges basename_nodes number_to_read k_value output_prefix edit_distance_threshold comment numbering_offset [-u UL_MAX] [-L LL_MAX] [-l LL_MIN] [-M MAX_BUBBLES] [-s] [-p] [-c] [-b]\n", name );
   fprintf( stderr, "\t [-u UL_MAX] Maximal length of the upper path of each bubble. Default: 1000\n" );
   fprintf( stderr, "\t [-L LL_MAX] Maximal length of the lower path of each bubble. Default: 2k-1\n" );
@@ -574,7 +574,7 @@ int main( int argc, char** argv )
   int required_sequence = atoi( argv[6] );
 
   int temoin;
-  while ( (temoin = getopt ( argc-11, &argv[11], "u:L:l:M:b:scp" )) != -1 ) 
+  while ( (temoin = getopt ( argc-11, &argv[11], "u:L:l:M:b:scp" )) != -1 )
   {
     switch ( temoin )
     {
@@ -606,7 +606,7 @@ int main( int argc, char** argv )
     case 's':
     {
       OUTPUT_SNPS = false;
-      fprintf(stderr, "Will not ouput SNPs and sequencing errors\n" );
+      fprintf(stderr, "Will not output SNPs and sequencing errors\n" );
       break;
     }
     case 'c':
@@ -640,11 +640,11 @@ int main( int argc, char** argv )
     // Set the label mapping, necessary only to read the edges
     for (int i = 0; i < nb_nodes; i++)
       label_to_node[label[i]] = i;
-    
+
     // This is a edge-weighted directed graph. The forward and reverse
     // node in the bidirected de Bruijn graph are split in two nodes.
     WeightedDigraph G(2 * nb_nodes);
-    
+
     for (int i = 0; i < (int)allEdges.size(); i++)
     {
       int u = label_to_node[allEdges[i].getFirst()]  +  (allEdges[i].label[0] == 'F' ? 0 : nb_nodes);
