@@ -59,20 +59,20 @@
 #define min(a, b) ((a) < (b) ? (a) : (b))
 int number_of_reads;
 
-
-// checks if, for a fragment, a tuple read/position mapped already (return 1) or none (return 0)
-int exists_tuple_read_position(const hash_t map, const char * starter, const int pos){
-	list * read_coherent_positions;                 //for one couple (read/fragment) : list of coherent mapped positions (usually, one position)
-	if(hash_entry_by_key(map, starter, (void **) (&read_coherent_positions)) !=0){
-		cell *c = ((list *)read_coherent_positions)->first;
-		while(c != NULL){
-			if((*(int *) (c->val))== pos){
-				return 1;}
-			c = c->prox;
-		}
-	}
-	return 0;
-}
+//
+//// checks if, for a fragment, a tuple read/position mapped already (return 1) or none (return 0)
+//int exists_tuple_read_position(const hash_t map, const char * starter, const int pos){
+//	list * read_coherent_positions;                 //for one couple (read/fragment) : list of coherent mapped positions (usually, one position)
+//	if(hash_entry_by_key(map, starter, (void **) (&read_coherent_positions)) !=0){
+//		cell *c = ((list *)read_coherent_positions)->first;
+//		while(c != NULL){
+//			if((*(int *) (c->val))== pos){
+//				return 1;}
+//			c = c->prox;
+//		}
+//	}
+//	return 0;
+//}
 
 void print_mapping(const int pos_on_fragment, const char * fragment, const char *read){
 	int i;
@@ -87,7 +87,6 @@ void print_mapping(const int pos_on_fragment, const char * fragment, const char
 
 
 
-// TODO: stop when all positions are bigger than a
 void feed_coherent_positions(p_fragment_info the_starter, const int start, const int length_read, const int qual, char *quality, int start_on_read, int read_file){
     int i, start_on_starter, stop_on_starter;
 	if(start<0) start_on_starter=0; else start_on_starter=start;
@@ -130,8 +129,7 @@ void feed_coherent_positions(p_fragment_info the_starter, const int start, const
     else{// lower path
       if(stop_on_starter-start_on_starter>size_seeds+min_overlap)
             the_starter->nb_reads_overlapping_both_AS_and_SB[read_file]++;
-//            else
-//                printf("%s\n%d\n",  the_starter->comment, the_starter->nb_reads_overlapping_both_AS_and_SB[read_file]);
+
     }
     
 #endif
@@ -175,10 +173,7 @@ void feed_coherent_positions(p_fragment_info the_starter, const int start, const
     //            ************************
     //                       <-----k----->
     //  00000000001111111111110000000000000000000000000000000000000000 the_starter->read_coherent_positions[read_file]
-	if(start+length_read-size_seeds<strlen(the_starter->w)) stop_on_starter=start+length_read-size_seeds; else stop_on_starter=strlen(the_starter->w);
-	//	printf("KMER SPANNING, STOP = %d\n", stop_on_starter);
-	//#else
-	//	printf("FULL SPANNING, STOP = %d\n", stop_on_starter);
+	if(start+length_read-minimal_read_overlap<strlen(the_starter->w)) stop_on_starter=start+length_read-minimal_read_overlap; else stop_on_starter=strlen(the_starter->w);
 #endif
     
 	for(i=start_on_starter;i<stop_on_starter;i++) Sinc8(the_starter->read_coherent_positions[read_file][i]);
@@ -218,14 +213,14 @@ int minimal_kmer_coverage(p_fragment_info the_starter, int read_file){
 void set_read_coherent(p_fragment_info the_starter, const int min_coverage, int read_file){
     int i;
     // V1: the whole fragment has to be k_read coherent or V2 where the last k positions have no influence on the coherency of the fragment.
-    // V2 is appropriate for the cases where the fragment is the end of a sequence (transcript, chromosome) and thus, no read are "longuer" than the sequence:
+    // V2 is appropriate for the cases where the fragment is the end of a sequence (transcript, chromosome) and thus, no read are "longer" than the sequence:
     //    ----------------- fragment
     //    °°°°°°°°°°°°        read
     //    °°°°°°°°°°°°     read
     //         °°°°°°°°°°°° read
     //         °°°°°°°°°°°° read
 #ifdef KMER_SPANNING
-    const int stop=strlen(the_starter->w)-size_seeds;
+    const int stop=strlen(the_starter->w)-minimal_read_overlap;
 #else
     const int stop=strlen(the_starter->w);
 #endif
@@ -235,42 +230,46 @@ void set_read_coherent(p_fragment_info the_starter, const int min_coverage, int
 
 
 ///////////////////////////////////////////////////////////////////////////////////////////////
-///// we use a boolean vector to know if a read was alread mapped at one position on a fragment
+///// we use a boolean vector to know if a read was alread mapped on a fragment
+// OCTOBER 2014: THIS SOLUTION IS NOT GOOD: some read maps several position of a fragment
+// (more and more true with long reads)
+// The new way of checking if a triplet (fragment/read/pwi) is already tested uses the fragment_info structure.
+// Each fragment info houses a listint where tested pwi values are stored for a read.
+// Each of these lists is emptied after each read mapping.
 ///////////////////////////////////////////////////////////////////////////////////////////////
-char mask [8];
-
-char * new_boleanVector (long size){
-    char* boolean_vector = (char*)malloc(size/8+1);
-    test_alloc(boolean_vector);
-    memset(boolean_vector, 0, size/8+1);
-    mask[0]=1;  //00000001
-    mask[1]=2;  //00000010
-    mask[2]=4;  //00000100
-    mask[3]=8;  //00001000
-    mask[4]=16; //00010000
-    mask[5]=32; //00100000
-    mask[6]=64; //01000000
-    mask[7]=128;//10000000
-    return boolean_vector;
-}
-
-
-char is_boolean_vector_visited (const char * boolean_vector, long i){
-    return (boolean_vector[i/8]&mask[i%8])==0?0:1;
-}
-
-void set_boolean_vector_visited(char * boolean_vector, long i){
-    boolean_vector[i/8]|=mask[i%8];
-}
-
-void free_boolean_vector(char * boolean_vector){
-    free(boolean_vector);
-}
-
-void reinit_boolean_vector(char * boolean_vector, long size){
-    memset(boolean_vector, 0, size/8+1);
-}
-
+//char mask [8];
+//
+//char * new_boleanVector (long size){
+//    char* boolean_vector = (char*)malloc(size/8+1);
+//    test_alloc(boolean_vector);
+//    memset(boolean_vector, 0, size/8+1);
+//    mask[0]=1;  //00000001
+//    mask[1]=2;  //00000010
+//    mask[2]=4;  //00000100
+//    mask[3]=8;  //00001000
+//    mask[4]=16; //00010000
+//    mask[5]=32; //00100000
+//    mask[6]=64; //01000000
+//    mask[7]=128;//10000000
+//    return boolean_vector;
+//}
+//
+//
+//char is_boolean_vector_visited (const char * boolean_vector, long i){
+//    return (boolean_vector[i/8]&mask[i%8])==0?0:1;
+//}
+//
+//void set_boolean_vector_visited(char * boolean_vector, long i){
+//    boolean_vector[i/8]|=mask[i%8];
+//}
+//
+//void free_boolean_vector(char * boolean_vector){
+//    free(boolean_vector);
+//}
+//
+//void reinit_boolean_vector(char * boolean_vector, long size){
+//    memset(boolean_vector, 0, size/8+1);
+//}
 
 
 
@@ -286,7 +285,7 @@ void reinit_boolean_vector(char * boolean_vector, long size){
  * returns the average read length
  */
 
-float read_coherence (FILE * reads_file,
+float read_coherence (gzFile reads_file,
                       char * reads_file_name,
                       const int k,
                       const int min_coverage,
@@ -298,15 +297,14 @@ float read_coherence (FILE * reads_file,
                       int nb_fragment_per_event,
                       FILE * sam_out,
                       int subst_allowed,
-                      const char no_subsutitution_on_central_position){
+                      const char no_subsutitution_on_central_position,
+                      const int minimal_read_overlap
+                      ){
     
 	//////////////////////////////////////////////////////////////////////////
 	/////////////// read all reads - storing those coherent with reads ///////
 	//////////////////////////////////////////////////////////////////////////
-	//double cumulated_size_reads=0;
-	char * seed = (char *) malloc (sizeof(char)*(k+1)); // fragment used for reading seeds
 	char * starter;
-    
     uint64_t offset_seed;
     uint64_t nb_seeds;
     
@@ -315,161 +313,193 @@ float read_coherence (FILE * reads_file,
     long int  read_number=0;
     
 	// map of starter -> position (for each read and direction, stores the starter and position already tested.)
-    char * boolean_vector = new_boleanVector(number_starters);
-    //	hash_t already_tested_direct = hash_create(1000);
-    //	hash_t already_tested_rev_comp = hash_create(1000);
+//    char * boolean_vector = new_boleanVector(number_starters);
     
     
 	// book space for the read that going to be read.
-    char * line =  (char *)malloc(sizeof(char)*1048576); // 1048576
+        char * readid =  (char *)malloc(sizeof(char)*1048576); // 1048576
+        char * qualityid =  (char *)malloc(sizeof(char)*1048576); // 1048576
 	char * read = (char *)malloc(sizeof(char)*16384); //
 	char * quality = (char *)malloc(sizeof(char)*16384);//
 	test_alloc(read);
 	test_alloc(quality);
-//	char * rev_comp_read = (char *)malloc(sizeof(char)*16384); //
-//	test_alloc(rev_comp_read);
-//	char * rev_comp_quality = (char *)malloc(sizeof(char)*16384); //
-//	test_alloc(rev_comp_quality);
-//	char starter_key[50]; // USED as key for hash table.
     
-	//number_of_reads=number_of_sequences_in_file(reads_file);
-    
-	//if(!silent){
-	//	printf("\n");                                         // print progress
-	//	for (i=0;i<100;i++) printf(" "); printf("] mapping reads\r[");       // print progress
-	//}
+    listint * tested_starters = listint_create(); // given a read, stores all starter ids on which a seed was seen. Enables to free quickly list of tested pwis of each tested starters.
+	
     char is_fastq=0;
     if ( qual || strstr(reads_file_name,"fastq") || strstr(reads_file_name,"fq") || strstr(reads_file_name,"txt") ) is_fastq=1;
 	// read all the reads
 	do{
-		//		int howmuchmapped=0; //DEB
-		//if(!silent) if((++extention_number)%(1+(number_of_reads/100)) == 0) printf(".");  // print progress
 		if(!silent) if((++read_number)%(100000) == 0) printf("\r %ld reads treated", read_number);  // print progress
 		if ( is_fastq )
-			read_len = get_next_sequence_for_fastq(reads_file, read, quality,line);
+			read_len = get_next_sequence_for_fastq(reads_file, read, quality,readid, qualityid);
 		else
-			read_len = get_next_fasta_sequence(reads_file, read,line);
+			read_len = get_next_fasta_sequence(reads_file, read,readid);
 		if(read_len<0) break; // we have read all the file.
-		//cumulated_size_reads+=read_len;
         
-//		// find the reverse complement of the read
-//		strcpy(rev_comp_read, read);
-//		revcomp(rev_comp_read,read_len);
-//		// if qual, find the reverse complement of the quality
-//		if ( qual )
-//		{
-//			strcpy(rev_comp_quality, quality);
-//			rev(rev_comp_quality,read_len);
-//		}
+        
+        const int minimal_pwi = minimal_read_overlap - read_len;
+        // The read must overlap the fragment with at least minimal_read_overlap positions.
+        // here is the first position on which the read may map :
+        //        ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  starter
+        //     **********       read (10)
+        //        <-----> minimal_read_overlap (7)
+        //     <-> -pwi (-3)
+        // -pwi+minimal_read_overlap <= |read|
+        // -pwi <= |read|-minimal_read_overlap
+        // pwi >= minimal_read_overlap-|read|
+        // pwi >= 7-10 = -3
+        // minimal_pwi = minimal_read_overlap-|read|
+        
         
 		stop = read_len-k+1;
-        //#ifdef DEBUG_MAPPING
-        //		printf("read = %s\n", read);
-        //#endif
+#ifdef DEBUG_MAPPING
+        		printf("new read = %s-\n", read);
+        #endif
 		// read all seeds present on the read:
         int direction;
+        kmer_type coded_seed;
+        char toinit=1;
+//        char validSeed;
         for(direction=0;direction<2;direction++){ // try the two possible directions of the read
-            for (i=0;i<stop;i++){
-                for(j=0;j<k;j++) seed[j]=read[i+j]; seed[j]='\0';// read the seed
+            toinit=1; // we have to init a new seed
+            for (i=0;i<stop;i++){ // for all possible seed on the read
+                if(toinit) {
+                    coded_seed=codeSeed(read+i); // init the seed
+                    toinit=0;
+                }
+                else { // previous seed was correct, we extend it.
+                    coded_seed=updateCodeSeed(read+i,&coded_seed); // utpdate the previous seed with a
+                }
+                if(get_seed_info(seeds_count,&coded_seed,&offset_seed,&nb_seeds)){
+                
                 
-                // if the seed is indexed in the fragments:
-                if(get_seed_info(seeds_count,seed,&offset_seed,&nb_seeds)){
                     // for each occurrence of this seed on the starter:
                     for (ii=offset_seed; ii<offset_seed+nb_seeds; ii++) {
-                        //while(c!=NULL){
-                        couple * value = &(seed_table[ii]);                        
-                        // if the tuple read/starter/position was not already mapped nor already detected as unmappable, and far enought from previous mapping of the same read try to map.
-//                        if(exists_tuple_read_position(already_tested_direct, starter_key, pwi)==0){
-                        if(is_boolean_vector_visited(boolean_vector, value->a)==0){
-                            set_boolean_vector_visited(boolean_vector, value->a);
-                            starter = all_starters[value->a]->w;
-                            //                        sprintf(starter_key, "%d", value->a);
-                            pwi = value->b-i; // starting position of the read on the starter.
-                            
-                            // overview situation:
-                            
-                            //        ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  starter
-                            //        <---------> b
-                            //                   [--------]                     seed
-                            //             ******************************       read
-                            //             <----> i
-                            //        <---> pwi
-
-                        
-#ifdef DEBUG_MAPPING
-                            printf("read = %s maps pos %d with %s (starter %d)\n", read, pwi, starter, value->a);
-#endif
- 
-                            if(no_subsutitution_on_central_position)
-                                read_coherence = read_coherent_SNP(pwi, starter, read, subst_allowed);
-                            else
-                                read_coherence = read_coherent_generic(pwi, starter, read, subst_allowed);
-
-                            
-                            if(read_coherence == 1){ // tuple read starter position is read coherent
-                                
-#ifdef DEBUG_MAPPING
-                                printf("SUCCESS %d %d \n", pwi, value->a);
-                                print_mapping(pwi,all_starters[value->a]->w ,read); //DEB
-#endif
-                                feed_coherent_positions(all_starters[value->a], pwi, (int)strlen(read), qual, quality, i, read_file);
-                                if( sam_out ) fprintf(sam_out,"%s\t%s\tC%d\t%d\n", all_starters[value->a]->comment, read, read_file+1, pwi);
-                                
-#ifdef DEBUG_QUALITY
-                                
-                                if ( qual )
-                                {
-                                    int l;
-                                    printf("\nstarter %d pwi=%d\n",value->a,pwi);
-                                    for(l=0;l<70;l++)printf(" ");
-                                    printf("%s\n",all_starters[value->a]->w);
-                                    for(l=0;l<70+pwi;l++)printf(" ");
-                                    printf("%s\n", read);
-                                    for(l=0;l<70+pwi;l++)printf(" ");
-                                    printf("%s\n", quality);
-                                }
-#endif
-                            } // end tuple read starter position is read coherent
-//                            hash_add_int_to_list(already_tested_direct, starter_key, pwi);
+                        couple * value = &(seed_table[ii]);
+//                        printf("value->a = %d\n", value->a); //DEB
+                        starter = all_starters[value->a]->w;
+                        if(all_starters[value->a]->mapped_with_current_read[read_file]==1) {
+//                            printf("already mapped %d with this read\n", value->a); //DEB
+                            continue; // a mach was already found with this starter, we consider only one match per couple (starter/read)
                         }
+                        //                        sprintf(starter_key, "%d", value->a);
+                        pwi = value->b-i; // starting position of the read on the starter.
+//                        printf("a=%d pwi = %d\n", value->a,pwi); // DEB
+                        if (listint_contains(all_starters[value->a]->tested_pwis_with_current_read[read_file],pwi)) {
+//                            printf("already tested %d position %d with this read\n", value->a, pwi); //DEB
+                            continue; // this reads was already (unsuccessfuly) tested with this starter at this position. No need to try it again.
+                        }
+                        if (numberInListint (all_starters[value->a]->tested_pwis_with_current_read[read_file])==0){ // this is the first time we meet this starter with this read, we add it in the list of met starters (in order to free the pwis lists of each encounted starters for this read)
+                            listint_add(tested_starters,value->a);
+//                            printf("adding %d in the list of tested starters with this read \n", *p_valuea); //DEB
+                        }
+                        listint_add(all_starters[value->a]->tested_pwis_with_current_read[read_file],pwi); // We store the fact that this read was already tested at this position on this starter.
+                        
+                        
+                        
+                        // overview general situation:
+                        
+                        //        ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  starter
+                        //        <---------> b
+                        //                   [--------]                     seed
+                        //             ******************************       read
+                        //             <----> i
+                        //        <---> pwi
+                        
+                        if (pwi<minimal_pwi) {
+                            continue; // this read to not overlap enough with the starter.
+                        }
+                        const int maximal_pwi = strlen(starter)-minimal_read_overlap;
+                        if (pwi > maximal_pwi) {
+                            continue; // this read to not overlap enough with the starter.
+                        }
+                        //        ;;;;;;;;;;;  starter (11)
+                        //             ******************************       read
+                        //             <----> minimal_read_overlap (6)
+                        //        <---> pwi (5)
+                        // |starter| <= pwi+minimal_read_overlap
+                        
+     
+                        read_coherence=0;
+                        if(no_subsutitution_on_central_position)
+                            read_coherence = read_coherent_SNP(pwi, starter, read, subst_allowed);
+                        else
+                            read_coherence = read_coherent_generic(pwi, starter, read, subst_allowed);
+                        
+                        
+                        if(read_coherence == 1){ // tuple read starter position is read coherent
+                            
+                            all_starters[value->a]->mapped_with_current_read[read_file]=1;
+                            
+                            
+#ifdef DEBUG_MAPPING
+                            printf("SUCCESS %d %d \n", pwi, value->a);
+                            print_mapping(pwi,all_starters[value->a]->w ,read); //DEB
+#endif
+                            feed_coherent_positions(all_starters[value->a], pwi, (int)strlen(read), qual, quality, i, read_file);
+                            if( sam_out ) fprintf(sam_out,"%d %d %s\t%s\tC%d\t%d\t%s", value->a, value->b, all_starters[value->a]->comment, read, read_file+1, pwi, readid);
+                            
+#ifdef DEBUG_QUALITY
+                            
+                            if ( qual )
+                            {
+                                int l;
+                                printf("\nstarter %d pwi=%d\n",value->a,pwi);
+                                for(l=0;l<70;l++)printf(" ");
+                                printf("%s\n",all_starters[value->a]->w);
+                                for(l=0;l<70+pwi;l++)printf(" ");
+                                printf("%s\n", read);
+                                for(l=0;l<70+pwi;l++)printf(" ");
+                                printf("%s\n", quality);
+                            }
+#endif
+                        } // end tuple read starter position is read coherent
+                        //                            hash_add_int_to_list(already_tested_direct, starter_key, pwi);
+                        
                         //c=c->prox;
                     }
-                }
+                } // end all infos for the current seed
             } // end all seeds of the read
             revcomp(read,read_len);
             if ( qual ) rev (quality,read_len);
-            reinit_boolean_vector(boolean_vector, number_starters);
+            
+            // free the lists of tested positions:
+            cellint * tested_starter=tested_starters->first;
+            while (tested_starter != NULL)
+            {
+                listint_empty(all_starters[tested_starter->val]->tested_pwis_with_current_read[read_file]);
+                all_starters[tested_starter->val]->mapped_with_current_read[read_file] = 0;
+//                printf("freeing starter %d\n", *(int *)tested_starter->val); //DEB
+                tested_starter=tested_starter->prox;
+            }
+            listint_empty(tested_starters);
+            
+            
         } // end both directions
         
-      
+        
 	}while(1); // end all reads of the file
     if(!silent) printf("\r %ld reads treated\n", read_number);  // print progress
-//	hash_delete(already_tested_direct, list_of_generic_free);
-//	hash_delete(already_tested_rev_comp, list_of_generic_free);
     
 	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	/////////////// for each starter: check those fully coherent and store left and right reads covering them ///////
 	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-    
-//	if(!silent){
-//		printf("]\n");                                         // print progress
-//		for (i=0;i<100;i++) printf(" "); printf("] reads coherence detection\r[");       // print progress
-//	}
+
     
 	for (starter_id=0;starter_id < nb_events_per_set*nb_fragment_per_event;starter_id++){
         if(!silent && (starter_id%(1+(nb_events_per_set/50)) == 0)) printf(".");  // print progress
         set_read_coherent(all_starters[starter_id], min_coverage, read_file);
 	} // end all fragments
     
-    //	if(!silent) printf("]\n");  // print progress
 	free(read);
     free(quality);
-    free_boolean_vector(boolean_vector);
-//	free(rev_comp_read);
-    free(line);
+    //free(line);
+    free(qualityid);
+    free(readid);
+    listint_free(tested_starters);
     
-	//return (float)(cumulated_size_reads/(float)number_of_reads);
-	return 0; 
+	return 0;
 }
 
 
